@@ -1,9 +1,9 @@
 # nocov start
 
-#' Extract meta information for articles
+#' Defunct: Extract meta information for articles
 #'
-#' `find_article()` extracts meta-data from JSTOR-XML files for journal
-#' articles.
+#' This function will be removed in the next release. Please use
+#' `jst_get_article()` instead.
 #'
 #' @param file_path A `.xml`-file for a journal-article.
 #'
@@ -39,11 +39,13 @@
 #' date.
 #'
 #' @export
-#' @examples 
+#' @examples
+#' \dontrun{ 
 #' find_article(jstor_example("sample_with_references.xml"))
+#' }
 find_article <- function(file_path) {
-  base::.Deprecated(msg = paste("`find_article` has been deprecated.",
-                                "Please use `jst_get_article` instead."))
+  base::.Defunct(msg = paste("`find_article` has been deprecated.",
+                                "Please use `jst_get_article()` instead."))
   xml_file <- read_jstor(file_path)
   
   validate_article(xml_file)
@@ -83,9 +85,10 @@ find_article <- function(file_path) {
   dplyr::bind_cols(basename_id, journal_ids, journal_title, article_ids, out)
 }
 
-#' Extract author information
+#' Defunct: Extract author information
 #'
-#' `find_authors()` extracts information about authors from JSTOR-XML files.
+#' This function will be removed in the next release. Please use
+#' `jst_get_authors()` instead.
 #'
 #' The function returns a `tibble` with the following six columns:
 #' - *prefix*: in case there was a prefix to the name, like `"Dr."`.
@@ -103,11 +106,13 @@ find_article <- function(file_path) {
 #' `NA_character`.
 #'
 #' @export
-#' @examples 
+#' @examples
+#' \dontrun{ 
 #' find_authors(jstor_example("sample_with_references.xml"))
+#' }
 find_authors <- function(file_path) {
-  base::.Deprecated(msg = paste("`find_authors` has been deprecated.",
-                                "Please use `jst_get_authors` instead."))
+  base::.Defunct(msg = paste("`find_authors` has been deprecated.",
+                                "Please use `jst_get_authors()` instead."))
   xml_file <- read_jstor(file_path)
   
   if (identical(xml2::xml_name(xml_file), "article")) {
@@ -123,8 +128,11 @@ find_authors <- function(file_path) {
 }
 
 
-#' Wrapper for file import
+#' Defunct: Wrapper for file import
 #'
+#' This function will be removed in the next release. Please use
+#' `jst_import()` instead.
+#' 
 #' This function applies an import function to a list of `xml`-files
 #' or a .zip-archive in case of `jstor_import_zip` and saves
 #' the output in batches of `.csv`-files to disk.
@@ -133,7 +141,7 @@ find_authors <- function(file_path) {
 #' many files easier:
 #' 
 #' - [purrr::safely()]
-#' - [foreach::foreach()]
+#' - `foreach::foreach()`
 #' - [readr::write_csv()]
 #' 
 #' When using one of the `find_*` functions, there should usually be no errors.
@@ -143,7 +151,7 @@ find_authors <- function(file_path) {
 #' 
 #' If you have many files to import, you might benefit from executing the
 #' function in parallel. We use
-#' \code{\link[snow:snow-startstop]{snow::createCluster()}} to setup a cluster
+#' \code{snow::createCluster()} to setup a cluster
 #' and
 #' then compute the results via `foreach` and \code{\%dopar\%}. The type of
 #' cluster is determined by `getClusterOption("type")`.
@@ -154,7 +162,7 @@ find_authors <- function(file_path) {
 #' Since you might run out of memory when importing a large quantity of files,
 #' the files to import are split up into batches. Each batch is being treated
 #' separately, therefore for each batch multiple processes from
-#' \code{\link[snow:snow-startstop]{snow::createCluster()}} are
+#' \code{snow::createCluster()} are
 #' spawned. For this reason, it is not recommended to have very small batches,
 #' as there is an overhead for starting and ending the processes. On the other
 #' hand, the batches should not be too large, to not exceed memory limitations.
@@ -183,7 +191,7 @@ find_authors <- function(file_path) {
 #'
 #' @seealso [jst_combine_outputs()]
 #' @export
-#' @examples 
+#' @examples
 #' \dontrun{
 #' # read from file list --------
 #' # find all files
@@ -206,8 +214,8 @@ jstor_import <- function(in_paths, out_file, out_path = NULL, .f,
                          files_per_batch = NULL,
                          cores = getOption("mc.cores", 1L),
                          show_progress = TRUE) {
-  base::.Deprecated(msg = paste("`jstor_import` has been deprecated.",
-                                "Please use `jst_import` instead."))
+  base::.Defunct(msg = paste("`jstor_import` has been deprecated.",
+                                "Please use `jst_import()` instead."))
   
   if (!is.null(n_batches) && !is.null(files_per_batch)) {
     stop("Either n_batches or files_per_batch needs to be specified, ",
@@ -252,7 +260,10 @@ jstor_import <- function(in_paths, out_file, out_path = NULL, .f,
           " file(s) in ", format(round(run_time, 2)), ".")
 }
 
-#' Extract meta information for books
+#' Defunct: Extract meta information for books
+#'
+#' This function will be removed in the next release. Please use
+#' `jst_get_book()` instead.
 #'
 #' `find_book()` extracts meta-data from JSTOR-XML files for book chapters.
 #'
@@ -282,11 +293,13 @@ jstor_import <- function(in_paths, out_file, out_path = NULL, .f,
 #' date.
 #' 
 #' @export
-#' @examples 
+#' @examples
+#' \dontrun{ 
 #' find_book(jstor_example("sample_book.xml"))
+#' }
 find_book <- function(file_path) {
-  base::.Deprecated(msg = paste("`find_book` has been deprecated.",
-                                "Please use `jst_get_book` instead."))
+  base::.Defunct(msg = paste("`find_book` has been deprecated.",
+                                "Please use `jst_get_book()` instead."))
   xml_file <- read_jstor(file_path)
   
   validate_book(xml_file)
@@ -314,8 +327,11 @@ find_book <- function(file_path) {
   tibble::new_tibble(out)
 }
 
-#' Extract information on book chapters
-#'
+#' Defunct: Extract information on book chapters
+#' 
+#' This function will be removed in the next release. Please use
+#' `jst_get_chapters()` instead.
+#' 
 #' `find_chapters()` extracts meta-data from JSTOR-XML files for book chapters.
 #' 
 #' Currently, `find_chapters()` is quite a lot slower than most of the other 
@@ -339,12 +355,14 @@ find_book <- function(file_path) {
 #' - part_title *(chr)*: The title of the part.
 #' - part_subtitle *(chr)*: The subtitle of the part, if specified.
 #' - authors *(list)*: A list-column with information on the authors. Can be
-#'   unnested with [tidyr::unnest()]. See the examples and [find_authors()].
+#'   unnested with [tidyr::unnest()]. See the examples
+#'   and [find_authors()].
 #' - abstract *(chr)*: The abstract to the part.
 #' - part_first_page *(chr)*: The page where the part begins.
 #' 
 #' @export
-#' @examples 
+#' @examples
+#' \dontrun{ 
 #' # extract parts without authors
 #' find_chapters(jstor_example("sample_book.xml"))
 #' 
@@ -353,9 +371,10 @@ find_book <- function(file_path) {
 #' parts
 #' 
 #' tidyr::unnest(parts)
+#' }
 find_chapters <- function(file_path, authors = FALSE) {
-  base::.Deprecated(msg = paste("`find_chapters` has been deprecated.",
-                                "Please use `jst_get_chapters` instead."))
+  base::.Defunct(msg = paste("`find_chapters` has been deprecated.",
+                                "Please use `jst_get_chapters()` instead."))
   xml_file <- read_jstor(file_path)
   
   validate_book(xml_file)
@@ -388,7 +407,10 @@ find_chapters <- function(file_path, authors = FALSE) {
   dplyr::bind_cols(base, parts_out)
 }
 
-#' Get path to jstor example
+#' Defunct: Get path to jstor example
+#' 
+#' This function will be removed in the next release. Please use
+#' `jst_example()` instead.
 #' 
 #' jstor includes several sample files for demonstration purposes. This helper
 #' makes them easy to access.
@@ -399,11 +421,13 @@ find_chapters <- function(file_path, authors = FALSE) {
 #' listed.
 #' @export
 #' @examples
+#' \dontrun{
 #' jstor_example()
 #' jstor_example("sample_with_references.xml") 
+#' }
 jstor_example <- function(path = NULL) {
-  base::.Deprecated(msg = paste("`jstor_example` has been deprecated.",
-                                "Please use `jst_example` instead."))
+  base::.Defunct(msg = paste("`jstor_example` has been deprecated.",
+                                "Please use `jst_example()` instead."))
   if (is.null(path)) {
     dir(system.file("extdata", package = "jstor"))
   } else {
@@ -411,8 +435,11 @@ jstor_example <- function(path = NULL) {
   }
 }
 
-#' Extract all footnotes
+#' Defunct: Extract all footnotes
 #'
+#' This function will be removed in the next release. Please use
+#' `jst_get_footnotes()` instead.
+#' 
 #' This function extracts the content of `fn-group` from journal-articles.
 #' 
 #' The `fn-group` usually contains footnotes corresponding to the article.
@@ -432,11 +459,13 @@ jstor_example <- function(path = NULL) {
 #' column `footnotes`.
 #' 
 #' @export
-#' @examples 
+#' @examples
+#' \dontrun{ 
 #' find_footnotes(jstor_example("sample_with_footnotes.xml"))
+#' }
 find_footnotes <- function(file_path) {
-  base::.Deprecated(msg = paste("`find_footnotes` has been deprecated.",
-                                "Please use `jst_get_footnotes` instead."))
+  base::.Defunct(msg = paste("`find_footnotes` has been deprecated.",
+                                "Please use `jst_get_footnotes()` instead."))
   xml_file <- read_jstor(file_path)
   
   validate_article(xml_file)
@@ -446,8 +475,11 @@ find_footnotes <- function(file_path) {
   expand_and_bind(file_path, footnotes)
 }
 
-#' Import full-text
+#' Defunct: Import full-text
 #'
+#' This function will be removed in the next release. Please use
+#' `jst_get_full_text()` instead.
+#' 
 #' This function imports the full_text contents of a JSTOR-article.
 #'
 #' @param filename The path to the file.
@@ -456,8 +488,8 @@ find_footnotes <- function(file_path) {
 #'
 #' @export
 read_full_text <- function(filename) {
-  base::.Deprecated(msg = paste("`read_full_text` has been deprecated.",
-                                "Please use `jst_get_full_text` instead."))
+  base::.Defunct(msg = paste("`read_full_text` has been deprecated.",
+                                "Please use `jst_get_full_text()` instead."))
   validate_file_path(filename, "txt")
   
   id <- get_basename(filename)
@@ -473,7 +505,10 @@ read_full_text <- function(filename) {
   )
 }
 
-#' Extract the basename of a path
+#' Defunct: Extract the basename of a path
+#' 
+#' This function will be removed in the next release. Please use
+#' `jst_get_file_name()` instead.
 #' 
 #' This helper simply extracts the basename of a path and removes the extension,
 #' e.g. `foo/bar.txt` is shortened to `bar`.
@@ -481,8 +516,8 @@ read_full_text <- function(filename) {
 #' @param file_path A path to a file
 #' @export
 get_basename <- function(file_path) {
-  base::.Deprecated(msg = paste("`get_basename` has been deprecated.",
-                                "Please use `jst_get_file_name` instead."))
+  base::.Defunct(msg = paste("`get_basename` has been deprecated.",
+                                "Please use `jst_get_file_name()` instead."))
   if (inherits(file_path, "jstor_zip")) {
     file_path[["file_path"]] %>% 
       basename() %>% 
@@ -493,8 +528,11 @@ get_basename <- function(file_path) {
   }
 }
 
-#' Extract all references
-#'
+#' Defunct: Extract all references
+#' 
+#' This function will be removed in the next release. Please use
+#' `jst_get_references()` instead.
+#' 
 #' This function extracts the content of `ref-list` from the `xml`-file.
 #' 
 #' This content may contain references or endnotes, depending on how the article
@@ -521,11 +559,13 @@ get_basename <- function(file_path) {
 #' - `references`: the text of the references.
 #'
 #' @export
-#' @examples 
+#' @examples
+#' \dontrun{ 
 #' find_references(jstor_example("sample_with_references.xml"))
+#' }
 find_references <- function(file_path) {
-  base::.Deprecated(msg = paste("`find_references` has been deprecated.",
-                                "Please use `jst_get_references` instead."))
+  base::.Defunct(msg = paste("`find_references` has been deprecated.",
+                                "Please use `jst_get_references()` instead."))
   xml_file <- read_jstor(file_path)
   
   validate_article(xml_file)
