@@ -160,36 +160,36 @@ references <- structure(
   list(
     file_name = "journal-article-standard_case", 
     ref_title = NA_character_,
-    authors = NA_character_,
-    editors = NA_character_,
-    collab = NA_character_,
-    title = NA_character_,
-    year = NA_character_,
-    source = NA_character_,
-    volume = NA_character_,
-    first_page = NA_character_,
-    last_page = NA_character_,
-    publisher = NA_character_,
-    publication_type = NA_character_,
-    unparsed_refs = NA_character_), row.names = c(NA, -1L), class = c("tbl_df", 
+    ref_authors = NA_character_,
+    ref_editors = NA_character_,
+    ref_collab = NA_character_,
+    ref_item_title = NA_character_,
+    ref_year = NA_character_,
+    ref_source = NA_character_,
+    ref_volume = NA_character_,
+    ref_first_page = NA_character_,
+    ref_last_page = NA_character_,
+    ref_publisher = NA_character_,
+    ref_publication_type = NA_character_,
+    ref_unparsed = NA_character_), row.names = c(NA, -1L), class = c("tbl_df", 
     "tbl", "data.frame"))
 
 references_wi_cont <- structure(
   list(
     file_name = "journal-article-standard_case", 
     ref_title = "References",
-    authors = NA_character_,
-    editors = NA_character_,
-    collab = NA_character_,
-    title = NA_character_,
-    year = NA_character_,
-    source = NA_character_,
-    volume = NA_character_,
-    first_page = NA_character_,
-    last_page = NA_character_,
-    publisher = NA_character_,
-    publication_type = NA_character_,
-    unparsed_refs = NA_character_), 
+    ref_authors = NA_character_,
+    ref_editors = NA_character_,
+    ref_collab = NA_character_,
+    ref_item_title = NA_character_,
+    ref_year = NA_character_,
+    ref_source = NA_character_,
+    ref_volume = NA_character_,
+    ref_first_page = NA_character_,
+    ref_last_page = NA_character_,
+    ref_publisher = NA_character_,
+    ref_publication_type = NA_character_,
+    ref_unparsed = NA_character_), 
   row.names = c(NA, -1L), 
   class = c("tbl_df", "tbl", "data.frame"))
 
